summaryrefslogtreecommitdiff
path: root/packaging/macosx/osx-app.sh
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2017-04-05 12:15:27 -0700
committerGuy Harris <guy@alum.mit.edu>2017-04-05 19:16:22 +0000
commit357cfd3b035d1ba6438e82cc1cbec105874206b6 (patch)
tree58a77b4dc8e1192db6278716b320bf42a18ded8f /packaging/macosx/osx-app.sh
parent1f94d34f43055ea47fc9426e1720bdb4b7397dd9 (diff)
downloadwireshark-357cfd3b035d1ba6438e82cc1cbec105874206b6.tar.gz
A bunch of "{Mac} OS X" -> "macOS" changes.
Avoid anachronisms, however; there was no "macOS 10.0" or even "OS X 10.0", for example. It was "Mac OS X" until 10.8 (although 10.7 was sometimes called "OS X" and sometimes called "Mac OS X"), and it was "OS X" from 10.8 to 10.11. Change-Id: Ie4a848997dcc6c45c2245c1fb84ec526032375c3 Reviewed-on: https://code.wireshark.org/review/20933 Reviewed-by: Guy Harris <guy@alum.mit.edu>
Diffstat (limited to 'packaging/macosx/osx-app.sh')
-rwxr-xr-xpackaging/macosx/osx-app.sh10
1 files changed, 5 insertions, 5 deletions
diff --git a/packaging/macosx/osx-app.sh b/packaging/macosx/osx-app.sh
index 158b930496..cb507ae17b 100755
--- a/packaging/macosx/osx-app.sh
+++ b/packaging/macosx/osx-app.sh
@@ -5,7 +5,7 @@
# -lp /path/to/wireshark/lib -ep /path/to/wireshark/extcap/binaries
# -pp /path/to/wireshark/plugins -p /path/to/Info.plist
#
# This script attempts to build an Wireshark.app bundle for OS X, resolving
# dynamic libraries, etc.
# It strips the executable and libraries if '-s' is given.
# The Info.plist file can be found in the base wireshark directory once
@@ -28,7 +28,7 @@
# NB:
# This originally came from Inkscape; Inkscape's configure script has an
# "--enable-osxapp", which causes some of Inkscape's installation data
# files to have OS X-ish paths under Contents/Resources of the bundle
# or under /Library/Application Support. We don't have such an option;
# we just put them in "bin", "etc", "lib", and "share" directories
# under Contents/Resources, rather than in the "bin", "etc", "lib",
@@ -97,7 +97,7 @@ fi
help()
{
echo -e "
-Create an app bundle for OS X
+Create an app bundle for macOS
USAGE
$0 [-s] [-l /path/to/libraries] -bp /path/to/wireshark/binaries -p /path/to/Info.plist
@@ -496,11 +496,11 @@ rpathify_file () {
fi
#
# Show the minimum supported version of OS X
# for each executable or library
#
if [[ "$filetype" = "EXECUTE" || "$filetype" = "DYLIB" ]] && [[ "$VERSION" -ge "7" ]] ; then
- echo "Minimum OS X version for $1:"
+ echo "Minimum macOS version for $1:"
otool -l $1 | grep -A3 LC_VERSION_MIN_MACOSX
fi
@@ -5,7 +5,7 @@
# -pp /path/to/wireshark/plugins -p /path/to/Info.plist
#
-# This script attempts to build an Wireshark.app bundle for OS X, resolving
+# This script attempts to build an Wireshark.app bundle for macOS, resolving
# dynamic libraries, etc.
# It strips the executable and libraries if '-s' is given.
@@ -28,7 +28,7 @@
# This originally came from Inkscape; Inkscape's configure script has an
# "--enable-osxapp", which causes some of Inkscape's installation data
-# files to have OS X-ish paths under Contents/Resources of the bundle
+# files to have macOS-ish paths under Contents/Resources of the bundle
# or under /Library/Application Support. We don't have such an option;
# we just put them in "bin", "etc", "lib", and "share" directories
@@ -496,11 +496,11 @@ rpathify_file () {
fi
#
- # Show the minimum supported version of OS X
+ # Show the minimum supported version of macOS
# for each executable or library
#